# Ant Colony Power Systems Optimizer

This library aims to provide a tool to solve an optimal dispach of Thermal Generation Units, using the Ant Colony Optimization algorithm, hence the library name acopoweropt (**A**nt **Co**lony **Power** **Opt**imizer)

> This is an under development library